<?php
namespace Application;

use Zend\Crypt\BlockCipher;
use Zend\Mvc\ModuleRouteListener;
use Zend\Mvc\MvcEvent;
use Zend\Session\Container;

/**
 * Class Module
 * @package Application
 */
class Module
{
    /**
     * @param MvcEvent $e
     */
    public function onBootstrap(MvcEvent $e)
    {
        $eventManager        = $e->getApplication()->getEventManager();
        $moduleRouteListener = new ModuleRouteListener();
        $moduleRouteListener->attach($eventManager);

        $Setting  = $e->getApplication()->getServiceManager()->get('Application\Model\Setting');
        $Demo     = $e->getApplication()->getServiceManager()->get('Application\Service\Demo');
        $ID       = $e->getApplication()->getServiceManager()->get('ControllerPluginManager')->get('WebStudioAuthentication')->getIdentity();
        $row      = $Setting->find(array('id' => $ID));
        $language = is_array($row) ? $row['language'] : $e->getApplication()->getServiceManager()->get('language_default');;
        $session = new Container('admin');

        $vm = $e->getViewModel();
        $vm->setVariable('fullname', sprintf('%s %s', $row['name'], $row['surname']));
        $vm->setVariable('gravatar', $row['email']);
        $vm->setVariable('last_accessed', $session->last_login);
        $vm->setVariable('demo', $Demo->getShowMessage());
        $vm->setVariable('lang', $language);
    }

    /**
     * @return mixed
     */
    public function getConfig()
    {
        return include __DIR__ . '/config/module.config.php';
    }

    /**
     * @return array
     */
    public function getAutoloaderConfig()
    {
        return array(
            'Zend\Loader\StandardAutoloader' => array(
                'namespaces' => array(
                    __NAMESPACE__ => __DIR__ . '/src/' . __NAMESPACE__,
                ),
            ),
        );
    }

    /**
     * @return array
     */
    public function getServiceConfig()
    {
        return array(
            'factories' => array(

                /** Model */
                'Application\Model\Account' => function ($sm) {
                        $dbAdapter = $sm->get('Zend\Db\Adapter\Adapter');
                        return new \Application\Model\AccountModel($dbAdapter);
                    },
                'Application\Model\Customers' => function ($sm) {
                        $dbAdapter = $sm->get('Zend\Db\Adapter\Adapter');
                        return new \Application\Model\CustomersModel($dbAdapter);
                    },
                'Application\Model\Domain' => function ($sm) {
                        $dbAdapter = $sm->get('Zend\Db\Adapter\Adapter');
                        return new \Application\Model\DomainModel($dbAdapter);
                    },
                'Application\Model\Hosting' => function ($sm) {
                        $dbAdapter = $sm->get('Zend\Db\Adapter\Adapter');
                        return new \Application\Model\HostingModel($dbAdapter);
                    },
                'Application\Model\Provider' => function ($sm) {
                        $dbAdapter = $sm->get('Zend\Db\Adapter\Adapter');
                        return new \Application\Model\ProviderModel($dbAdapter);
                    },
                'Application\Model\Setting' => function ($sm) {
                        $dbAdapter = $sm->get('Zend\Db\Adapter\Adapter');
                        return new \Application\Model\SettingModel($dbAdapter);
                    },
                'Application\Model\TypeAccount' => function ($sm) {
                        $dbAdapter = $sm->get('Zend\Db\Adapter\Adapter');
                        return new \Application\Model\TypeAccountModel($dbAdapter);
                    },
                'Application\Model\Upload' => function ($sm) {
                        $dbAdapter = $sm->get('Zend\Db\Adapter\Adapter');
                        return new \Application\Model\UploadModel($dbAdapter);
                    },
                'Application\Model\Server' => function ($sm) {
                        $dbAdapter = $sm->get('Zend\Db\Adapter\Adapter');
                        return new \Application\Model\ServerModel($dbAdapter);
                    },
            )
        );
    }

    /**
     * @return array
     */
    public function getControllerPluginConfig()
    {
        return array(
            'factories' => array(

                /** Authentication */
                'WebStudioAuthentication' => function ($sm) {
                        $serviceLocator       = $sm->getServiceLocator();
                        $authService          = $serviceLocator->get('Application\AuthService');
                        $authAdapterWebStudio = $serviceLocator->get('Application\AuthAdapter\WebStudio');
                        $controllerPlugin     = new Controller\Plugin\WebStudioAuthentication();
                        $controllerPlugin->setAuthService($authService);
                        $controllerPlugin->setAuthAdapter($authAdapterWebStudio);
                        return $controllerPlugin;
                    },

                /** API key mcrypt */
                'ApiKey' => function ($sm) {
                        $serviceLocator   = $sm->getServiceLocator();
                        $controllerPlugin = new Controller\Plugin\ApiKey();
                        $controllerPlugin->setModelSetting($serviceLocator->get('Application\Model\Setting'));
                        return $controllerPlugin;
                    },

                /** Mail */
                'mailerZF2' => function ($sm) {
                        $serviceLocator = $sm->getServiceLocator();
                        $BC             = $serviceLocator->get('block_cipher');

                        $blockCipher  = BlockCipher::factory('mcrypt', array('algo' => $BC['algo']));
                        $settingModel = $serviceLocator->get('Application\Model\Setting');

                        if ($serviceLocator->get('ControllerPluginManager')->get('WebStudioAuthentication')->hasIdentity()) {

                            $blockCipher->setKey($serviceLocator->get('ControllerPluginManager')->get('ApiKey')->getApiKey());
                            $setting = $settingModel->find(array(
                                'id' => $serviceLocator->get('ControllerPluginManager')->get('WebStudioAuthentication')->getIdentity()
                            ));

                        } else {

                            $session = new Container('lost_password');
                            $token   = $session->token;
                            $setting = $settingMododel->find(array(
                                'token' => $token
                            ));
                            $blockCipher->setKey($setting['api_key']);
                        }

                        if (!isset($setting['from_mail'])) {
                            throw new \Exception('Configuring mail not set.');
                        }

                        $renderer = new \Zend\View\Renderer\PhpRenderer();
                        $resolver = new \Zend\View\Resolver\TemplatePathStack();
                        $resolver->setPaths(array(
                            __DIR__ . '/../../module/'
                        ));
                        $renderer->setResolver($resolver);
                        $controllerPlugin = new Controller\Plugin\Mailer($renderer);

                        $mail = $setting['from_mail'];
                        $name = $setting['from_name'];
                        $controllerPlugin->setFrom($mail, $name);

                        switch ($setting['send_email']) {
                            case '1':
                                $transport = new \Zend\Mail\Transport\Sendmail();
                                $controllerPlugin->setMailTransport($transport);
                                break;

                            case '2':
                                $transport = new \Zend\Mail\Transport\Smtp();
                                $options   = new \Zend\Mail\Transport\SmtpOptions(array(
                                    'host' => $setting['host'],
                                    'port' => $setting['port'],
                                    'connection_class' => 'login',
                                    'connection_config' => array(
                                        'ssl' => 'tls',
                                        'username' => $setting['username'],
                                        'password' => $blockCipher->decrypt($setting['password']),
                                    ),
                                ));
                                $transport->setOptions($options);
                                $controllerPlugin->setMailTransport($transport);
                                break;
                        }
                        return $controllerPlugin;
                    },
            )
        );
    }
}
