<?php

namespace Application\Authentication\Adapter;

use Application\Model\SettingModel;
use Zend\Authentication\Adapter\AdapterInterface;
use Zend\Authentication\Result;
use Zend\Crypt\Password\Bcrypt;
use Zend\Session\Container;

/**
 * Class WebStudio
 * @package Application\Authentication\Adapter
 */
class WebStudio implements AdapterInterface
{
    /**
     * @var \Zend\Crypt\Password\Bcrypt
     */
    protected $_bcrypt;

    /**
     * @var
     */
    protected $_username;

    /**
     * @var
     */
    protected $_password;

    /**
     * @var
     */
    protected $_settingModel;

    /**
     * @param SettingModel $settingModel
     */
    public function __construct(SettingModel $settingModel)
    {
        $this->_bcrypt = new Bcrypt();
        $this->setSettingModel($settingModel);
    }

    /**
     * @return Result
     */
    public function authenticate()
    {
        if (empty($this->_username) || empty($this->_password)) {
            return new Result(Result::FAILURE, null);
        }

        $hashPassword = $this->getSettingModel()->find(array(
            'usermail' => $this->_username
        ));

        $code = $this->_bcrypt->verify($this->_password, $hashPassword['pwd']) ? Result::SUCCESS : Result::FAILURE;

        /* last_access */
        if ($code === Result::SUCCESS) {
        	
        	$infoUser = $this->getSettingModel()->find(array(
        		'id' => $hashPassword['id']
        	));
        	
        	$session = new Container('admin');
        	$session->last_login = $infoUser['last_accessed'];
        	
        	//update last login
            $this->getSettingModel()->touch($hashPassword['id']);
        }

        return new Result($code, $hashPassword['id']);
    }

    /**
     * @param $username
     */
    public function setUsername($username)
    {
        $this->_username = $username;
    }

    /**
     * @param $password
     */
    public function setPassword($password)
    {
        $this->_password = $password;
    }

    /**
     * @param $type
     */
    public function setType($type)
    {
        $this->type = $type;
    }

    /**
     * @return mixed
     */
    public function getSettingModel()
    {
        return $this->_settingModel;
    }

    /**
     * @param $_settingModel
     */
    public function setSettingModel($_settingModel)
    {
        $this->_settingModel = $_settingModel;
    }
}
