<?php
namespace Application\Controller;

use Application\Filter\AccountFilter;
use Application\Form\AccountForm;
use Application\Model\AccountModel;
use Application\Model\DomainModel;
use Zend\Crypt\BlockCipher;
use Zend\Mvc\Controller\AbstractActionController;
use Zend\View\Model\ViewModel;

/**
 * Class AccountController
 * @package Application\Controller
 */
class AccountController extends AbstractActionController
{
    /**
     * @var AccountModel
     */
    protected $_AccountModel;

    /**
     * @var AccountForm
     */
    protected $_AccountForm;

    /**
     * @var DomainModel
     */
    protected $_DomainModel;

    /**
     * @param \Application\Form\AccountForm $AccountForm
     */
    public function setAccountForm($AccountForm)
    {
        $this->_AccountForm = $AccountForm;
    }

    /**
     * @return \Application\Form\AccountForm
     */
    public function getAccountForm()
    {
        return $this->_AccountForm;
    }

    /**
     * @param \Application\Model\AccountModel $AccountModel
     */
    public function setAccountModel($AccountModel)
    {
        $this->_AccountModel = $AccountModel;
    }

    /**
     * @return \Application\Model\AccountModel
     */
    public function getAccountModel()
    {
        return $this->_AccountModel;
    }

    /**
     * @param \Application\Model\DomainModel $DomainModel
     */
    public function setDomainModel($DomainModel)
    {
        $this->_DomainModel = $DomainModel;
    }

    /**
     * @return \Application\Model\DomainModel
     */
    public function getDomainModel()
    {
        return $this->_DomainModel;
    }

    /**
     * Account Domain
     * @return array|ViewModel
     */
    public function indexAction()
    {
        $domain = (int)$this->params()->fromRoute('domain', 0);

        return new ViewModel(array(
            'domain' => $this->getDomainModel()->find(array('d.id' => $domain)),
            'account' => $this->getAccountModel()->getList(array('id_domain' => $domain)),
            'message' => $this->flashMessenger()->getMessages()
        ));
    }

    /**
     * Add Account
     * @return \Zend\Http\Response|ViewModel
     */
    public function addAction()
    {
        $domain  = (int)$this->params()->fromRoute('domain', 0);
        $request = $this->getRequest();
        $form    = $this->getAccountForm();
        $BC      = $this->getServiceLocator()->get('block_cipher');
        
        $blockCipher = BlockCipher::factory('mcrypt', array('algo' => $BC['algo']));
        $blockCipher->setKey($this->ApiKey()->getApiKey());

        if (true === $request->isPost()) {

            $post              = $request->getPost()->toArray();
            $post['id_domain'] = $domain;
            if(!empty($post['pwd']))
            {
            	$post['pwd'] = $blockCipher->encrypt($post['pwd']);
            }

            $form->setData($post);
            $form->setInputFilter(new AccountFilter());

            if (true === $form->isValid()) {
                $this->getAccountModel()->insert($post);
                $this->flashMessenger()->addMessage(array('success', 1));
                return $this->redirect()->toRoute('account', array('domain' => $domain));
            }
        }

        return new ViewModel(array(
            'domain' => $domain,
            'form' => $form
        ));
    }

    /**
     * Edit Account
     * @return \Zend\Http\Response|ViewModel
     */
    public function editAction()
    {
        $domain = (int)$this->params()->fromRoute('domain', 0);
        $ID     = (int)$this->params()->fromRoute('id', 0);
        $BC     = $this->getServiceLocator()->get('block_cipher');
        
        $blockCipher = BlockCipher::factory('mcrypt', array('algo' => $BC['algo']));
        $blockCipher->setKey($this->ApiKey()->getApiKey());
        $row = $this->getAccountModel()->find(array('a.id' => $ID));
        
        if(!empty($row['pwd']))
        {
        	$row['pwd'] = $blockCipher->decrypt($row['pwd']);
        }
                
        $request = $this->getRequest();
        $form    = $this->getAccountForm();
        $form->setData($row);

        if (true === $request->isPost()) {

            $post = $request->getPost()->toArray();
            
            if(!empty($post['pwd']))
            {
            	$post['pwd'] = $blockCipher->encrypt($post['pwd']);
            }

            $form->setData($post);
            $form->setInputFilter(new AccountFilter());

            if (true === $form->isValid()) {
                $this->getAccountModel()->update($ID, $post);
                $this->flashMessenger()->addMessage(array('success', 1));
                return $this->redirect()->toRoute('account', array('domain' => $domain));
            }
        }

        return new ViewModel(array(
            'domain' => $domain,
            'form' => $form
        ));
    }

    /**
     * Edit Account
     * @return \Zend\Http\Response
     */
    public function deleteAction()
    {
        $domain = (int)$this->params()->fromRoute('domain', 0);
        $ID     = (int)$this->params()->fromRoute('id', 0);
        $this->getAccountModel()->delete($ID);
        $this->flashMessenger()->addMessage(array('success', 1));
        return $this->redirect()->toRoute('account', array('domain' => $domain));
    }
}
