<?php
namespace Application\Controller;

use Application\Filter\CustomersFilter;
use Application\Form\CustomersForm;
use Application\Model\CustomersModel;
use Zend\Mvc\Controller\AbstractActionController;
use Zend\View\Model\ViewModel;

/**
 * Class CustomersController
 * @package Application\Controller
 */
class CustomersController extends AbstractActionController
{
    /**
     * @var CustomersModel
     */
    protected $_CustomersModel;

    /**
     * @var CustomersForm
     */
    protected $_CustomersForm;

    /**
     * @param \Application\Model\CustomersModel $CustomersModel
     */
    public function setCustomersModel($CustomersModel)
    {
        $this->_CustomersModel = $CustomersModel;
    }

    /**
     * @return \Application\Model\CustomersModel
     */
    public function getCustomersModel()
    {
        return $this->_CustomersModel;
    }

    /**
     * @param \Application\Form\CustomersForm $CustomersForm
     */
    public function setCustomersForm($CustomersForm)
    {
        $this->_CustomersForm = $CustomersForm;
    }

    /**
     * @return \Application\Form\CustomersForm
     */
    public function getCustomersForm()
    {
        return $this->_CustomersForm;
    }

    /**
     * Customers
     * @return array|ViewModel
     */
    public function indexAction()
    {
        return new ViewModel(array(
            'customers' => $this->getCustomersModel()->getList(),
            'message' => $this->flashMessenger()->getMessages()
        ));
    }

    /**
     * Add Customers
     * @return \Zend\Http\Response|ViewModel
     */
    public function addAction()
    {
        $request = $this->getRequest();
        $form    = $this->getCustomersForm();
        $Adapter = $this->getServiceLocator()->get('Zend\Db\Adapter\Adapter');

        if (true === $request->isPost()) {

            $post            = $request->getPost()->toArray();
            $post['created'] = date('Y-m-d H:i:s');

            $form->setData($post);
            $form->setInputFilter(new CustomersFilter($Adapter, 0));

            if (true === $form->isValid()) {
                $this->getCustomersModel()->insert($post);
                $this->flashMessenger()->addMessage(array('success', 1));
                return $this->redirect()->toRoute('customers');
            }
        }

        return new ViewModel(array(
            'form' => $form
        ));
    }

    /**
     * Edit Customers
     * @return \Zend\Http\Response|ViewModel
     */
    public function editAction()
    {
        $ID      = (int)$this->params()->fromRoute('id', 0);
        $row     = $this->getCustomersModel()->find(array('id' => $ID));
        $Adapter = $this->getServiceLocator()->get('Zend\Db\Adapter\Adapter');

        $request = $this->getRequest();
        $form    = $this->getCustomersForm();
        $form->setData($row);

        if (true === $request->isPost()) {

            $post = $request->getPost()->toArray();
            $form->setData($post);
            $form->setInputFilter(new CustomersFilter($Adapter, $ID));

            if (true === $form->isValid()) {
                $this->getCustomersModel()->update($ID, $post);
                $this->flashMessenger()->addMessage(array('success', 1));
                return $this->redirect()->toRoute('customers');
            }
        }

        return new ViewModel(array(
            'form' => $form
        ));
    }

    /**
     * Delete Customers
     * @return \Zend\Http\Response
     */
    public function deleteAction()
    {
        $ID = (int)$this->params()->fromRoute('id', 0);
        $this->getCustomersModel()->delete($ID);
        $this->flashMessenger()->addMessage(array('success', 1));
        return $this->redirect()->toRoute('customers');
    }
}
