<?php
namespace Application\Controller;

use Application\Form\LoginForm;
use Application\Service\Demo;
use Zend\Mvc\Controller\AbstractActionController;
use Zend\View\Model\ViewModel;

/**
 * Class IndexController
 * @package Application\Controller
 */
class IndexController extends AbstractActionController
{
    /**
     * @var LoginForm
     */
    protected $_loginForm;

    /**
     * @var InstallForm
     */
    protected $_installForm;

    /**
     * @var InstallService
     */
    protected $_installService;

    /**
     * @var Demo
     */
    protected $_Demo;

    /**
     * @param \Application\Service\Demo $Demo
     */
    public function setDemo($Demo)
    {
        $this->_Demo = $Demo;
    }

    /**
     * @return \Application\Service\Demo
     */
    public function getDemo()
    {
        return $this->_Demo;
    }

    /**
     * Login
     * @return array|\Zend\Http\Response|ViewModel
     */
    public function indexAction()
    {
        $form = $this->getLoginForm();

        if ($this->getInstallService()->getInstall()) {
            return $this->redirect()->toRoute('install');
        }

        if ($this->WebStudioAuthentication()->hasIdentity()) {
            return $this->redirect()->toRoute('dashboard');
        }

        return new ViewModel(array(
            'form' => $form,
            'demo' => $this->getDemo()->getShowMessage(),
            'messages' => $this->flashmessenger()->getMessages()
        ));
    }

    /**
     * Auth
     * @return mixed|\Zend\Http\Response
     */
    public function authAction()
    {
        $request = $this->getRequest();
        $form    = $this->getLoginForm();

        if ($request->isPost()) {
            $form->setData($request->getPost());

            if (!$form->isValid()) {
                $this->flashMessenger()->addMessage(array('danger', 1));
                return $this->redirect()->toRoute('home');
            }

            $data    = $form->getData();
            $adapter = $this->WebStudioAuthentication()->getAuthAdapter();
            $adapter->setUsername($data['usermail']);
            $adapter->setPassword($data['password']);

            $auth = $this->WebStudioAuthentication()->getAuthService()->authenticate($adapter);

            if (!$auth->isValid()) {
                $this->flashMessenger()->addMessage(array('danger', 1));
                return $this->redirect()->toRoute('home');
            }
            return $this->redirect()->toRoute('dashboard');
        }
        return $this->redirect()->toRoute('home');
    }

    /**
     * Install
     * @return array|\Zend\Http\Response|ViewModel
     */
    public function installAction()
    {
        if (!$this->getInstallService()->getInstall()) {
            return $this->redirect()->toRoute('dashboard');
        }

        $request = $this->getRequest();
        $form    = $this->getInstallForm();

        if ($request->isPost()) {

            $post               = $request->getPost()->toArray();
            $post['send_email'] = 1;
            $form->setData($post);

            if (true === $form->isValid()) {
                $install = $this->getInstallService()->install($post);
                if (true === $install) {
                    $this->flashMessenger()->addMessage(array('success', 1));
                    return $this->redirect()->toRoute('welcome');
                }
            }
        }

        return new ViewModel(array(
            'form' => $form,
        ));
    }

    /**
     * Welcome
     * @return array|\Zend\Http\Response|ViewModel
     */
    public function welcomeAction()
    {
        if ($this->getInstallService()->getInstall()) {
            return $this->redirect()->toRoute('install');
        }

        return new ViewModel(array(
            'messages' => $this->flashmessenger()->getMessages()
        ));
    }

    /**
     * Logout
     * @return \Zend\Http\Response
     */
    public function logoutAction()
    {
        $this->WebStudioAuthentication()->getAuthService()->clearIdentity();
        return $this->redirect()->toRoute('home');
    }

    /**
     * @return the $_loginForm
     */
    public function getLoginForm()
    {
        return $this->_loginForm;
    }

    /**
     * @param field_type $_loginForm
     */
    public function setLoginForm($_loginForm)
    {
        $this->_loginForm = $_loginForm;
    }

    /**
     * @return the $_installForm
     */
    public function getInstallForm()
    {
        return $this->_installForm;
    }

    /**
     * @param the $_installForm
     */
    public function setInstallForm($_installForm)
    {
        $this->_installForm = $_installForm;
    }

    /**
     * @return the $_installService
     */
    public function getInstallService()
    {
        return $this->_installService;
    }

    /**
     * @param the $_installService
     */
    public function setInstallService($_installService)
    {
        $this->_installService = $_installService;
    }
}
