<?php
namespace Application\Controller;

use Application\Service\Demo;
use Zend\Crypt\BlockCipher;
use Zend\Mvc\Controller\AbstractActionController;
use Zend\Session\Container;
use Zend\View\Model\ViewModel;

/**
 * Class PasswordController
 * @package Application\Controller
 */
class LostPasswordController extends AbstractActionController
{
    /**
     * @var LostPasswordForm
     */
    protected $_lostPasswordForm;

    /**
     * @var ResetPasswordForm
     */
    protected $_resetPasswordForm;

    /**
     * @var SettingModel
     */
    protected $_settingModel;

    /**
     * @var Demo
     */
    protected $_Demo;

    /**
     * @param \Application\Service\Demo $Demo
     */
    public function setDemo($Demo)
    {
        $this->_Demo = $Demo;
    }

    /**
     * @return \Application\Service\Demo
     */
    public function getDemo()
    {
        return $this->_Demo;
    }

    /**
     * @return the $_lostPasswordForm
     */
    public function getLostPasswordForm()
    {
        return $this->_lostPasswordForm;
    }

    /**
     * @param \Application\Controller\LostPasswordForm $_lostPasswordForm
     */
    public function setLostPasswordForm($_lostPasswordForm)
    {
        $this->_lostPasswordForm = $_lostPasswordForm;
    }

    /**
     * @return the $_resetPasswordForm
     */
    public function getResetPasswordForm()
    {
        return $this->_resetPasswordForm;
    }

    /**
     * @param \Application\Controller\ResetPasswordForm $_resetPasswordForm
     */
    public function setResetPasswordForm($_resetPasswordForm)
    {
        $this->_resetPasswordForm = $_resetPasswordForm;
    }

    /**
     * @return the $_settingModel
     */
    public function getSettingModel()
    {
        return $this->_settingModel;
    }

    /**
     * @param \Application\Controller\SettingModel $_settingModel
     */
    public function setSettingModel($_settingModel)
    {
        $this->_settingModel = $_settingModel;
    }

    /**
     * index
     * @return array|\Zend\Http\Response|ViewModel
     */
    public function indexAction()
    {
        $form    = $this->getLostPasswordForm();
        $request = $this->getRequest();

        if (true === $request->isPost()) {

            if ($this->getDemo()->getSendEmail() === true) {

                $post = $request->getPost()->toArray();
                $form->setData($post);

                if (true === $form->isValid()) {
                    $setting = $this->getSettingModel()->find(array(
                        'email' => $post['email']
                    ));

                    if (empty($setting)) {
                        $this->flashMessenger()->addMessage(array('danger', 1));
                        return $this->redirect()->toRoute('lost-password');
                    }

                    return $this->redirect()->toRoute('lost-password/default', array('action' => 'reset', 'token' => $setting['token']));
                }
            }
        }

        return new ViewModel(array(
        	'demo' => $this->getDemo()->getShowMessage(),
            'form' => $form,
            'messages' => $this->flashMessenger()->getMessages()
        ));
    }

    public function resetAction()
    {
        $token   = $this->params()->fromRoute('token', 0);
        $request = $this->getRequest();
        $setting = $this->getSettingModel()->find(array(
            'token' => $token
        ));

        if (empty($setting)) {
            return $this->redirect()->toRoute('lost-password');
        }

        $form = $this->getResetPasswordForm();

        if (true === $request->isPost()) {
            $post = $request->getPost()->toArray();
            $form->setData($post);

            if (true === $form->isValid()) {

                $BC = $this->getServiceLocator()->get('block_cipher');

                $blockCipher = BlockCipher::factory('mcrypt', array('algo' => $BC['algo']));
                $blockCipher->setKey($setting['api_key']);

                if ($blockCipher->decrypt($setting['answer']) == $post['answer']) {
                    $bcrypt         = new \Zend\Crypt\Password\Bcrypt();
                    $setting['pwd'] = \Zend\Math\Rand::getString(8);
                    $pwd_crypt      = $bcrypt->create($setting['pwd']);

                    $this->getSettingModel()->update($setting['id'], array(
                        'pwd' => $pwd_crypt,
                    ));

                    $session        = new Container('lost_password');
                    $session->token = $token;

                    $sm        = $this->getServiceLocator()->get('ServiceManager');
                    $translate = $sm->get('ViewHelperManager')->get('translate');

                    $view = new ViewModel(array(
                        'user' => $setting,
                    ));
                    $view->setTerminal(true);
                    $view->setTemplate(sprintf('Application/view/email/lost_password_%s', $setting['language']));
                    $this->mailerZF2()->send(array(
                        'to' => $setting['email'],
                        'subject' => $translate('label_67', null, $setting['language']),
                    ), $view);

                    $this->flashMessenger()->addMessage(array('success', 1));
                    return $this->redirect()->toRoute('lost-password/default', array('action' => 'reset', 'token' => $token));

                } else {

                    $this->flashMessenger()->addMessage(array('danger', 1));
                    return $this->redirect()->toRoute('lost-password/default', array('action' => 'reset', 'token' => $token));
                }
            }
        }

        return new ViewModel(array(
            'form' => $form,
            'setting' => $setting,
            'messages' => $this->flashMessenger()->getMessages()
        ));
    }
}
