<?php
namespace Application\Controller;

use Application\Form\ProviderForm;
use Application\Model\ProviderModel;
use Zend\Crypt\BlockCipher;
use Zend\Mvc\Controller\AbstractActionController;
use Zend\View\Model\ViewModel;

/**
 * Class ProviderController
 * @package Application\Controller
 */
class ProviderController extends AbstractActionController
{
    /**
     * @var ProviderForm
     */
    protected $_ProviderForm;

    /**
     * @var ProviderModel
     */
    protected $_ProviderModel;

    /**
     * @param \Application\Form\ProviderForm $ProviderForm
     */
    public function setProviderForm($ProviderForm)
    {
        $this->_ProviderForm = $ProviderForm;
    }

    /**
     * @return \Application\Form\ProviderForm
     */
    public function getProviderForm()
    {
        return $this->_ProviderForm;
    }

    /**
     * @param \Application\Model\ProviderModel $ProviderModel
     */
    public function setProviderModel($ProviderModel)
    {
        $this->_ProviderModel = $ProviderModel;
    }

    /**
     * @return \Application\Model\ProviderModel
     */
    public function getProviderModel()
    {
        return $this->_ProviderModel;
    }

    /**
     * Provider
     * @return array|ViewModel
     */
    public function indexAction()
    {
        return new ViewModel(array(
            'provider' => $this->getProviderModel()->getList(),
            'message' => $this->flashMessenger()->getMessages()
        ));
    }

    /**
     * Add Provider
     * @return \Zend\Http\Response|ViewModel
     */
    public function addAction()
    {
        $request = $this->getRequest();
        $form    = $this->getProviderForm();
        $BC      = $this->getServiceLocator()->get('block_cipher');
        $blockCipher = BlockCipher::factory('mcrypt', array('algo' => $BC['algo']));
        $blockCipher->setKey($this->ApiKey()->getApiKey());

        if (true === $request->isPost()) {

            $post = $request->getPost()->toArray();
            
            if(!empty($post['pwd']))
            {
            	$post['pwd'] = $blockCipher->encrypt($post['pwd']);
            }
            
            $form->setData($post);

            if (true === $form->isValid()) {
                $this->getProviderModel()->insert($post);
                $this->flashMessenger()->addMessage(array('success', 1));
                return $this->redirect()->toRoute('provider');
            }
        }

        return new ViewModel(array(
            'form' => $form
        ));
    }

    /**
     * Edit Provider
     * @return \Zend\Http\Response|ViewModel
     */
    public function editAction()
    {
        $ID  = (int)$this->params()->fromRoute('id', 0);
        $row = $this->getProviderModel()->find(array('id' => $ID));
        
        $BC = $this->getServiceLocator()->get('block_cipher');
        $blockCipher = BlockCipher::factory('mcrypt', array('algo' => $BC['algo']));
        $blockCipher->setKey($this->ApiKey()->getApiKey());

        $request = $this->getRequest();
        $form    = $this->getProviderForm();
        
        if(!empty($row['pwd']))
        {
        	$row['pwd'] = $blockCipher->decrypt($row['pwd']);
        }

        $form->setData($row);

        if (true === $request->isPost()) {

            $post = $request->getPost()->toArray();
            if(!empty($post['pwd']))
            {
            	$post['pwd'] = $blockCipher->encrypt($post['pwd']);
            }
            $form->setData($post);

            if (true === $form->isValid()) {
                $this->getProviderModel()->update($ID, $post);
                $this->flashMessenger()->addMessage(array('success', 1));
                return $this->redirect()->toRoute('provider');
            }
        }

        return new ViewModel(array(
            'form' => $form
        ));
    }

    /**
     * Delete Provider
     * @return \Zend\Http\Response
     */
    public function deleteAction()
    {
        $ID = (int)$this->params()->fromRoute('id', 0);
        $this->getProviderModel()->delete($ID);
        $this->flashMessenger()->addMessage(array('success', 1));
        return $this->redirect()->toRoute('provider');
    }
}
