<?php
namespace Application\Controller;

use Application\Form\SettingForm;
use Application\Model\SettingModel;
use Application\Service\Demo;
use Zend\Crypt\BlockCipher;
use Zend\Crypt\Password\Bcrypt;
use Zend\Mvc\Controller\AbstractActionController;
use Zend\View\Model\ViewModel;

/**
 * Class SettingController
 * @package Application\Controller
 */
class SettingController extends AbstractActionController
{
    /**
     * @var SettingForm
     */
    protected $_SettingForm;

    /**
     * @var $_SmtpForm
     */
    protected $_SmtpForm;

    /**
     * @var SettingModel
     */
    protected $_SettingModel;

    /**
     * @var $_SmtpModel
     */
    protected $_SmtpModel;

    /**
     * @var Demo
     */
    protected $_Demo;

    /**
     * @param \Application\Service\Demo $Demo
     */
    public function setDemo($Demo)
    {
        $this->_Demo = $Demo;
    }

    /**
     * @return \Application\Service\Demo
     */
    public function getDemo()
    {
        return $this->_Demo;
    }

    /**
     * @param \Application\Form\SettingForm $SettingForm
     */
    public function setSettingForm($SettingForm)
    {
        $this->_SettingForm = $SettingForm;
    }

    /**
     * @return \Application\Form\SettingForm
     */
    public function getSettingForm()
    {
        return $this->_SettingForm;
    }

    /**
     * @return the $_SmtpForm
     */
    public function getSmtpForm()
    {
        return $this->_SmtpForm;
    }

    /**
     * @param \Application\Controller\ $_SmtpForm $_SmtpForm
     */
    public function setSmtpForm($_SmtpForm)
    {
        $this->_SmtpForm = $_SmtpForm;
    }

    /**
     * @param \Application\Model\SettingModel $SettingModel
     */
    public function setSettingModel($SettingModel)
    {
        $this->_SettingModel = $SettingModel;
    }

    /**
     * @return \Application\Model\SettingModel
     */
    public function getSettingModel()
    {
        return $this->_SettingModel;
    }

    /**
     * @return the $_SmtpModel
     */
    public function getSmtpModel()
    {
        return $this->_SmtpModel;
    }

    /**
     * @param field_type $_SmtpModel
     */
    public function setSmtpModel($_SmtpModel)
    {
        $this->_SmtpModel = $_SmtpModel;
    }

    /**
     * Setting
     * @return array|\Zend\Http\Response|ViewModel
     */
    public function indexAction()
    {
        $ID      = $this->WebStudioAuthentication()->getIdentity();
        $row     = $this->getSettingModel()->find(array('id' => $ID));
        $request = $this->getRequest();

        $form       = $this->getSettingForm();
        $old_pwd    = $row['pwd'];
        $row['pwd'] = null;
        $form->setData($row);

        if (true === $request->isPost()) {

            $post = $request->getPost()->toArray();

            if (!empty($post['pwd'])) {
                $bcrypt      = new Bcrypt();
                $post['pwd'] = $bcrypt->create($post['pwd']);
            } else {
                $post['pwd'] = $old_pwd;
            }
            $form->setData($post);

            if (true === $form->isValid()) {

                if ($this->getDemo()->getWriteDatabase() === true) {
                    $this->getSettingModel()->update($ID, $post);
                }

                $this->flashMessenger()->addMessage(array('success', 1));
                return $this->redirect()->toRoute('setting');
            }
        }

        return new ViewModel(array(
        	'demo' => $this->getDemo()->getShowMessage(), 	
            'form' => $form,
            'message' => $this->flashMessenger()->getMessages()
        ));
    }

    /**
     * Setting Email
     * @return \Zend\Http\Response|ViewModel
     */
    public function smtpAction()
    {
        $ID  = $this->WebStudioAuthentication()->getIdentity();
        $row = $this->getSettingModel()->find(array('id' => $ID));
        $BC  = $this->getServiceLocator()->get('block_cipher');

        $blockCipher = BlockCipher::factory('mcrypt', array('algo' => $BC['algo']));
        $blockCipher->setKey($this->ApiKey()->getApiKey());

        $request = $this->getRequest();
        $form    = $this->getSmtpForm();
        if (!empty($row['password'])) {
            $row['password'] = $blockCipher->decrypt($row['password']);
        }

        $form->setData($row);

        if (true === $request->isPost()) {

            $post = $request->getPost()->toArray();
            if (!empty($post['password'])) {
                $post['password'] = $blockCipher->encrypt($post['password']);
            }

            $id_user = $this->WebStudioAuthentication()->getIdentity();

            $form->setData($post);

            if (true === $form->isValid()) {

                if ($this->getDemo()->getWriteDatabase() === true) {
                    $this->getSettingModel()->update($id_user, $post);
                }

                $this->flashMessenger()->addMessage(array('success', 1));
                return $this->redirect()->toRoute('smtp');
            }
        }

        return new ViewModel(array(
        	'demo' => $this->getDemo()->getShowMessage(),
            'form' => $form,
            'message' => $this->flashMessenger()->getMessages()
        ));
    }
}
