<?php
namespace Application\Controller;

use Application\Form\TypeAccountForm;
use Application\Model\TypeAccountModel;
use Zend\Mvc\Controller\AbstractActionController;
use Zend\View\Model\ViewModel;

/**
 * Class TypeAccountController
 * @package Application\Controller
 */
class TypeAccountController extends AbstractActionController
{
    /**
     * @var TypeAccountModel
     */
    protected $_TypeAccountModel;

    /**
     * @var TypeAccountForm
     */
    protected $_TypeAccountForm;

    /**
     * @param \Application\Form\TypeAccountForm $TypeAccountForm
     */
    public function setTypeAccountForm($TypeAccountForm)
    {
        $this->_TypeAccountForm = $TypeAccountForm;
    }

    /**
     * @return \Application\Form\TypeAccountForm
     */
    public function getTypeAccountForm()
    {
        return $this->_TypeAccountForm;
    }

    /**
     * @param \Application\Model\TypeAccountModel $TypeAccountModel
     */
    public function setTypeAccountModel($TypeAccountModel)
    {
        $this->_TypeAccountModel = $TypeAccountModel;
    }

    /**
     * @return \Application\Model\TypeAccountModel
     */
    public function getTypeAccountModel()
    {
        return $this->_TypeAccountModel;
    }

    /**
     * Type Account
     * @return array|ViewModel
     */
    public function indexAction()
    {
        return new ViewModel(array(
            'account' => $this->getTypeAccountModel()->getList(),
            'message' => $this->flashMessenger()->getMessages()
        ));
    }

    /**
     * Add Type Account
     * @return \Zend\Http\Response|ViewModel
     */
    public function addAction()
    {
        $request = $this->getRequest();
        $form    = $this->getTypeAccountForm();

        if (true === $request->isPost()) {

            $post = $request->getPost()->toArray();
            $form->setData($post);

            if (true === $form->isValid()) {
                $this->getTypeAccountModel()->insert($post);
                $this->flashMessenger()->addMessage(array('success', 1));
                return $this->redirect()->toRoute('type_account');
            }
        }

        return new ViewModel(array(
            'form' => $form
        ));
    }

    /**
     * Edit Type Account
     * @return \Zend\Http\Response|ViewModel
     */
    public function editAction()
    {
        $ID  = (int)$this->params()->fromRoute('id', 0);
        $row = $this->getTypeAccountModel()->find(array('id' => $ID));

        $request = $this->getRequest();
        $form    = $this->getTypeAccountForm();
        $form->setData($row);

        if (true === $request->isPost()) {

            $post = $request->getPost()->toArray();
            $form->setData($post);

            if (true === $form->isValid()) {
                $this->getTypeAccountModel()->update($ID, $post);
                $this->flashMessenger()->addMessage(array('success', 1));
                return $this->redirect()->toRoute('type_account');
            }
        }

        return new ViewModel(array(
            'form' => $form
        ));
    }

    /**
     * Edit Type Account
     * @return \Zend\Http\Response
     */
    public function deleteAction()
    {
        $ID = (int)$this->params()->fromRoute('id', 0);
        $this->getTypeAccountModel()->delete($ID);
        $this->flashMessenger()->addMessage(array('success', 1));
        return $this->redirect()->toRoute('type_account');
    }
}
