<?php
namespace Application\Controller;

use Application\Form\UploadForm;
use Application\Model\DomainModel;
use Application\Model\UploadModel;
use Application\Service\Demo;
use Zend\Mvc\Controller\AbstractActionController;
use Zend\View\Model\ViewModel;

/**
 * Class UploadController
 * @package Application\Controller
 */
class UploadController extends AbstractActionController
{
    /**
     * @var int
     */
    private static $max = 50000000;

    /**
     * @var array
     */
    private static $extension = array('pdf', 'txt', 'zip', 'sql', 'rar', 'odt', 'doc', 'png', 'jpeg', 'jpg','gif');

    /**
     * @var UploadModel
     */
    protected $_UploadModel;

    /**
     * @var UploadForm
     */
    protected $_UploadForm;

    /**
     * @var DomainModel
     */
    protected $_DomainModel;

    /**
     * @var Demo
     */
    protected $_Demo;

    /**
     * @param \Application\Service\Demo $Demo
     */
    public function setDemo($Demo)
    {
        $this->_Demo = $Demo;
    }

    /**
     * @return \Application\Service\Demo
     */
    public function getDemo()
    {
        return $this->_Demo;
    }

    /**
     * @param \Application\Model\DomainModel $DomainModel
     */
    public function setDomainModel($DomainModel)
    {
        $this->_DomainModel = $DomainModel;
    }

    /**
     * @return \Application\Model\DomainModel
     */
    public function getDomainModel()
    {
        return $this->_DomainModel;
    }

    /**
     * @param \Application\Form\UploadForm $UploadForm
     */
    public function setUploadForm($UploadForm)
    {
        $this->_UploadForm = $UploadForm;
    }

    /**
     * @return \Application\Form\UploadForm
     */
    public function getUploadForm()
    {
        return $this->_UploadForm;
    }

    /**
     * @param \Application\Model\UploadModel $UploadModel
     */
    public function setUploadModel($UploadModel)
    {
        $this->_UploadModel = $UploadModel;
    }

    /**
     * @return \Application\Model\UploadModel
     */
    public function getUploadModel()
    {
        return $this->_UploadModel;
    }

    /**
     * File Domain
     * @return array|ViewModel
     */
    public function indexAction()
    {
        $domain = (int)$this->params()->fromRoute('domain', 0);

        return new ViewModel(array(
            'domain' => $domain,
            'account' => $this->getUploadModel()->getList(array('id_domain' => $domain)),
            'message' => $this->flashMessenger()->getMessages()
        ));
    }

    /**
     * Add File Domain
     * @return array|ViewModel
     */
    public function addAction()
    {
        $domain     = (int)$this->params()->fromRoute('domain', 0);
        $row_domain = $this->getDomainModel()->find(array('d.id' => $domain));
        $request    = $this->getRequest();
        $form       = $this->getUploadForm();

        if (true === $request->isPost()) {

            $nonFile              = $request->getPost()->toArray();
            $nonFile['id_domain'] = $domain;
            $File                 = $this->params()->fromFiles('upload');

            $data = array_merge($nonFile, array('upload' => $File['name']));
            $form->setData($data);

            if (true === $form->isValid()) {

                /** Validator */
                $size      = new \Zend\Validator\File\Size(array('max' => self::$max));
                $extension = new \Zend\Validator\File\Extension(array('extension' => self::$extension));

                /** Adapter per i Validator */
                $adapter = new \Zend\File\Transfer\Adapter\Http();
                $adapter->setValidators(array($size, $extension), $File['name']);

                /**
                 * se ci sono errori mostro un array con il messaggio
                 * altrimenti se esiste un file da mandare sul server
                 * eseguo l'upload... salvo cmq i dati sul database
                 */
                if (!$adapter->isValid()) {

                    $dataError = $adapter->getMessages();
                    $error     = array();
                    foreach ($dataError as $key => $row) {
                        $error[] = $row;
                    }
                    $form->setMessages(array('upload' => $error));

                } else {

                    if ($this->getDemo()->getWriteDatabase() === true) {
                        /** upload file server */
                        $adapter->setDestination('./data/upload');
                        if ($adapter->receive($File['name'])) {
                            // \Zend\Debug\Debug::dump($data);
                            $this->getUploadModel()->insert($data);
                            $this->flashMessenger()->addMessage(array('success', 1));
                            return $this->redirect()->toRoute('upload', array('domain' => $domain));
                        }
                    }
                }
            }
        }

        return new ViewModel(array(
            'domain' => $row_domain,
            'form' => $form,
            'demo' => $this->getDemo()->getShowMessage(),
        ));
    }

    /**
     * Edit File Domain
     * @return \Zend\Http\Response|ViewModel
     */
    public function editAction()
    {
        $domain     = (int)$this->params()->fromRoute('domain', 0);
        $ID         = (int)$this->params()->fromRoute('id', 0);
        $row_domain = $this->getDomainModel()->find(array('d.id' => $domain));
        $row        = $this->getUploadModel()->find(array('id' => $ID));
        $request    = $this->getRequest();
        $form       = $this->getUploadForm();

        $form->setData($row);

        if (true === $request->isPost()) {

            $nonFile              = $request->getPost()->toArray();
            $nonFile['id_domain'] = $domain;
            $File                 = $this->params()->fromFiles('upload');

            if ($File['name']) {
                /** @var assegno il nuovo nome afl file $data */
                $data = array_merge($nonFile, array('upload' => $File['name']));
            } else {
                $data = array_merge($nonFile, array('upload' => $row['upload']));

            }
            $form->setData($data);

            if (true === $form->isValid()) {

                /** Validator */
                $size      = new \Zend\Validator\File\Size(array('max' => self::$max));
                $extension = new \Zend\Validator\File\Extension(array('extension' => self::$extension));

                /** Adapter per i Validator */
                $adapter = new \Zend\File\Transfer\Adapter\Http(array('ignoreNoFile' => true));
                $adapter->setValidators(array($size, $extension), $File['name']);

                /**
                 * se ci sono errori mostro un array con il messaggio
                 * altrimenti se esiste un file da mandare sul server
                 * eseguo l'upload... salvo cmq i dati sul database
                 */
                if (!$adapter->isValid()) {

                    $dataError = $adapter->getMessages();
                    $error     = array();
                    foreach ($dataError as $key => $row) {
                        $error[] = $row;
                    }
                    $form->setMessages(array('upload' => $error));

                } else {

                    if (!empty($File['name'])) {
                        $upload = sprintf('./data/upload/%s', $row['upload']);
                        if (file_exists($upload)) {
                            unlink($upload);
                        }
                    }

                    if ($this->getDemo()->getWriteDatabase() === true) {
                        /** upload file server */
                        $adapter->setDestination('./data/upload');
                        if ($adapter->receive($File['name'])) {
                            // \Zend\Debug\Debug::dump($data);
                            $this->getUploadModel()->update($ID, $data);
                            $this->flashMessenger()->addMessage(array('success', 1));
                            return $this->redirect()->toRoute('upload', array('domain' => $domain));
                        }
                    }
                }
            }
        }

        return new ViewModel(array(
            'domain' => $row_domain,
            'form' => $form,
            'demo' => $this->getDemo()->getShowMessage(),
        ));
    }

    /**
     * Delete File Domain
     * @return \Zend\Http\Response
     */
    public function deleteAction()
    {
        $domain = (int)$this->params()->fromRoute('domain', 0);
        $ID     = (int)$this->params()->fromRoute('id', 0);

        $row = $this->getUploadModel()->find(array('id' => $ID));
        $this->getUploadModel()->delete($ID);

        $upload = sprintf('./data/upload/%s', $row['upload']);
        if (file_exists($upload)) {
            unlink($upload);
        }

        $this->flashMessenger()->addMessage(array('success', 1));
        return $this->redirect()->toRoute('upload', array('domain' => $domain));
    }

    /**
     * Download File
     * @return \Zend\Stdlib\ResponseInterface
     */
    public function downloadAction()
    {
        $domain = (int)$this->params()->fromRoute('domain', 0);
        $ID     = (int)$this->params()->fromRoute('id', 0);

        $row      = $this->getUploadModel()->find(array('id' => $ID));
        $fileName = sprintf('./data/upload/%s', $row['upload']);

        if (!is_file($fileName)) {
            $this->getResponse()->setStatusCode(404);
            return;
        }

        $fileContents = file_get_contents($fileName);

        $response = $this->getResponse();
        $response->setContent($fileContents);

        $headers = $response->getHeaders();
        $headers->clearHeaders()
            ->addHeaderLine('Content-Type', 'whatever your content type is')
            ->addHeaderLine('Content-Disposition', 'attachment; filename="' . $row['upload'] . '"')
            ->addHeaderLine('Content-Length', strlen($fileContents));
        return $this->response;
    }
}
