<?php
namespace Application\Factory;

use Application\Controller\AccountController;
use Application\Filter\AccountFilter;
use Application\Form\AccountForm;
use Zend\ServiceManager\FactoryInterface;
use Zend\ServiceManager\ServiceLocatorInterface;

/**
 * Class AccountFactory
 * @package Application\Factory
 */
class AccountFactory implements FactoryInterface
{
    /**
     * @param ServiceLocatorInterface $servicelocator
     * @return AccountController|mixed
     */
    public function createService(ServiceLocatorInterface $servicelocator)
    {
        $allServices      = $servicelocator->getServiceLocator();
        $sm               = $allServices->get('ServiceManager');
        $SqlObjectToArray = $sm->get('Application\Service\SqlObjectToArray');

        $form = new AccountForm('', array(
            'type_account' => $SqlObjectToArray->getOptionValue('TypeAccount'),
        ));
        $form->setInputFilter(new AccountFilter());

        $controller = new AccountController();
        $controller->setAccountModel($sm->get('Application\Model\Account'));
        $controller->setDomainModel($sm->get('Application\Model\Domain'));
        $controller->setAccountForm($form);
        return $controller;
    }
}
