<?php
namespace Application\Factory;

use Application\Controller\DomainController;
use Application\Form\DomainForm;
use Application\Form\SendForm;
use Zend\ServiceManager\FactoryInterface;
use Zend\ServiceManager\ServiceLocatorInterface;

/**
 * Class DomainFactory
 * @package Application\Factory
 */
class DomainFactory implements FactoryInterface
{
    /**
     * @param ServiceLocatorInterface $servicelocator
     * @return DomainController|mixed
     */
    public function createService(ServiceLocatorInterface $servicelocator)
    {
        $allServices      = $servicelocator->getServiceLocator();
        $sm               = $allServices->get('ServiceManager');
        $SqlObjectToArray = $sm->get('Application\Service\SqlObjectToArray');

        $controller = new DomainController();
        $controller->setDomainModel($sm->get('Application\Model\Domain'));
        $controller->setAccountModel($sm->get('Application\Model\Account'));
        $controller->setUploadModel($sm->get('Application\Model\Upload'));
        $controller->setCustomersModel($sm->get('Application\Model\Customers'));
        $controller->setSettingModel($sm->get('Application\Model\Setting'));
        $controller->setDemo($sm->get('Application\Service\Demo'));
        $controller->setDomainForm(new DomainForm('', array(
            'provider' => $SqlObjectToArray->getOptionValue('Provider'),
            'hosting' => $SqlObjectToArray->getOptionValue('Hosting'),
            'type_ftp' => $sm->get('type_ftp'),
            'customers' => $SqlObjectToArray->getOptionValue('Customers'),
            'server' => $SqlObjectToArray->getOptionValue('Server'),
        )));
        $controller->setSendForm(new SendForm());
        return $controller;
    }
}
