<?php
namespace Application\Factory;

use Application\Controller\IndexController;
use Application\Filter\InstallFilter;
use Application\Filter\LoginFilter;
use Application\Form\InstallForm;
use Application\Form\LoginForm;
use Zend\ServiceManager\FactoryInterface;
use Zend\ServiceManager\ServiceLocatorInterface;

/**
 * Class IndexFactory
 * @package Application\Factory
 */
class IndexFactory implements FactoryInterface
{
    /**
     * @param ServiceLocatorInterface $servicelocator
     * @return IndexController|mixed
     */
    public function createService(ServiceLocatorInterface $servicelocator)
    {
        $allServices = $servicelocator->getServiceLocator();
        $sm          = $allServices->get('ServiceManager');
        $translate   = $sm->get('ViewHelperManager')->get('translate');
        $lang        = $sm->get('language_default');

        /** @var Form $form_install */
        $form_install = new InstallForm('', array(
            'language' => $sm->get('language'),
            'label_29' => $translate('label_29', null, $lang),
            'label_49' => $translate('label_49', null, $lang),
            'label_13' => $translate('label_13', null, $lang),
            'label_16' => $translate('label_16', null, $lang),
            'label_14' => $translate('label_14', null, $lang),
            'label_55' => $translate('label_55', null, $lang),
            'label_56' => $translate('label_56', null, $lang)
        ));
        $form_install->setInputFilter(new InstallFilter());

        /** @var Form $form_login */
        $form_login = new LoginForm();
        $form_login->setInputFilter(new LoginFilter());

        $controller = new IndexController();
        $controller->setLoginForm($form_login);
        $controller->setInstallForm($form_install);
        $controller->setInstallService($sm->get('Application\Service\Install'));
        $controller->setDemo($sm->get('Application\Service\Demo'));
        return $controller;
    }
}
