<?php
namespace Application\Factory;

use Application\Controller\LostPasswordController;
use Application\Form\LostPasswordForm;
use Application\Form\ResetForm;
use Zend\ServiceManager\FactoryInterface;
use Zend\ServiceManager\ServiceLocatorInterface;

/**
 * Class LostPasswordFactory
 * @package Application\Factory
 */
class LostPasswordFactory implements FactoryInterface
{
    /**
     * @param ServiceLocatorInterface $servicelocator
     * @return LostPasswordController|mixed
     */
    public function createService(ServiceLocatorInterface $servicelocator)
    {
        $allServices = $servicelocator->getServiceLocator();
        $sm          = $allServices->get('ServiceManager');
        $translate   = $sm->get('ViewHelperManager')->get('translate');
        $lang        = $sm->get('language_default');

        /** @var Form $form_lastpassword */
        $form_lastpassword = new LostPasswordForm('', array(
            'language' => $sm->get('language'),
            'label_16' => $translate('label_16', null, $lang),
            'label_59' => $translate('label_59', null, $lang),
        ));

        /** @var Form $form_resetpassword */
        $form_resetpassword = new ResetForm('', array(
            'language' => $sm->get('language'),
            'label_56' => $translate('label_56', null, $lang),
        ));

        $controller = new LostPasswordController();
        $controller->setLostPasswordForm($form_lastpassword);
        $controller->setResetPasswordForm($form_resetpassword);
        $controller->setSettingModel($sm->get('Application\Model\Setting'));
        $controller->setDemo($sm->get('Application\Service\Demo'));
        return $controller;
    }
}