<?php
namespace Application\Factory;

use Zend\ServiceManager\FactoryInterface;
use Zend\ServiceManager\ServiceLocatorInterface;
use Application\Controller\ServerController;
use Application\Form\ServerForm;
use Application\Filter\ServerFilter;

/**
 * Class DomainFactory
 * @package Application\Factory
 */
class ServerFactory implements FactoryInterface
{
    /**
     * @param ServiceLocatorInterface $servicelocator
     * @return DomainController|mixed
     */
    public function createService(ServiceLocatorInterface $servicelocator)
    {
        $allServices  = $servicelocator->getServiceLocator();
        $sm           = $allServices->get('ServiceManager');
        $SqlObjectToArray = $sm->get('Application\Service\SqlObjectToArray');

        $form = new ServerForm('', array(
            'provider' => $SqlObjectToArray->getOptionValue('Provider'),
            'hosting' => $SqlObjectToArray->getOptionValue('Hosting'),
            'customers' => $SqlObjectToArray->getOptionValue('Customers')
        ));
        $form->setInputFilter(new ServerFilter());
        
        $controller = new ServerController();
        $controller->setServerModel($sm->get('Application\Model\Server'));
        $controller->setServerForm($form);
        return $controller;
    }
}
