<?php
namespace Application\Filter;

use Zend\InputFilter\InputFilter;

/**
 * Class CustomersFilter
 * @package Application\Filter
 */
class CustomersFilter extends InputFilter
{
    /**
     * @param $dbAdapter
     * @param int $id
     */
    public function __construct($dbAdapter, $id = 0)
    {
        $this->add(array(
            'name' => 'fullname',
            'required' => true,
            'filters' => array(
                array('name' => 'StripTags'),
                array('name' => 'StringTrim')
            ),
            'validators' => array(
                array(
                    'name' => 'StringLength',
                    'options' => array(
                        'encoding' => 'UTF-8',
                        'min' => '1',
                        'max' => '45'
                    )
                )
            )
        ));

        $this->add(array(
            'name' => 'email',
            'required' => true,
            'filters' => array(
                array('name' => 'StripTags'),
                array('name' => 'StringTrim')
            ),
            'validators' => array(
                array(
                    'name' => 'StringLength',
                    'options' => array(
                        'encoding' => 'UTF-8',
                        'min' => '1',
                        'max' => '45'
                    )
                ),
                array(
                    'name' => 'EmailAddress',
                    'options' => array(
                        'messages' => array(
                            'emailAddressInvalidFormat' => 'Email address format is not invalid'
                        )
                    )
                ),
                array(
                    'name' => 'Db\NoRecordExists',
                    'options' => array(
                        'adapter' => $dbAdapter,
                        'table' => 'ws_customers',
                        'field' => 'email',
                        'exclude' => array(
                            'field' => 'id',
                            'value' => $id
                        )
                    )
                ),
                array(
                    'name' => 'NotEmpty',
                    'options' => array(
                        'messages' => array(
                            'isEmpty' => 'Email address is required'
                        )
                    )
                )
            )
        ));

        $this->add(array(
            'name' => 'phone',
            'required' => true,
            'filters' => array(
                array('name' => 'StripTags'),
                array('name' => 'StringTrim')
            ),
            'validators' => array(
                array(
                    'name' => 'StringLength',
                    'options' => array(
                        'encoding' => 'UTF-8',
                        'min' => '1',
                        'max' => '45'
                    )
                )
            )
        ));
    }
}
