<?php
namespace Application\Filter;

use Zend\InputFilter\InputFilter;

/**
 * Class DomainFilter
 * @package Application\Filter
 */
class DomainFilter extends InputFilter
{
    /**
     * @param $dbAdapter
     * @param int $id
     */
    public function __construct($dbAdapter, $id = 0)
    {
        $this->add(array(
            'name' => 'fullname',
            'required' => true,
            'filters' => array(
                array('name' => 'StripTags'),
                array('name' => 'StringTrim')
            ),
            'validators' => array(
                array(
                    'name' => 'StringLength',
                    'options' => array(
                        'encoding' => 'UTF-8',
                        'min' => '1',
                        'max' => '45'
                    )
                )
            )
        ));

        $this->add(array(
            'name' => 'url',
            'required' => true,
            'filters' => array(
                array('name' => 'StripTags'),
                array('name' => 'StringTrim')
            ),
            'validators' => array(
                array(
                    'name' => 'StringLength',
                    'options' => array(
                        'encoding' => 'UTF-8',
                        'min' => '1',
                        'max' => '45'
                    )
                ),
                array(
                    'name' => 'Hostname',
                    'options' => array(
                        'allow' => \Zend\Validator\Hostname::ALLOW_DNS, // Allow these hostnames
                        'useIdnCheck' => true, // Check IDN domains
                        'useTldCheck' => true, // Check TLD elements
                        'ipValidator' => null, // IP validator to use
                    ),
                ),
                array(
                    'name' => 'Db\NoRecordExists',
                    'options' => array(
                        'adapter' => $dbAdapter,
                        'table' => 'ws_domain',
                        'field' => 'url',
                        'exclude' => array(
                            'field' => 'id',
                            'value' => $id
                        )
                    )
                )
            )
        ));

        $this->add(array(
            'name' => 'host_ftp',
            'required' => true,
            'filters' => array(
                array('name' => 'StripTags'),
                array('name' => 'StringTrim')
            ),
            'validators' => array(
                array(
                    'name' => 'StringLength',
                    'options' => array(
                        'encoding' => 'UTF-8',
                        'min' => '1',
                        'max' => '45'
                    )
                )
            )
        ));

        $this->add(array(
            'name' => 'user_ftp',
            'required' => true,
            'filters' => array(
                array('name' => 'StripTags'),
                array('name' => 'StringTrim')
            ),
            'validators' => array(
                array(
                    'name' => 'StringLength',
                    'options' => array(
                        'encoding' => 'UTF-8',
                        'min' => '1',
                        'max' => '45'
                    )
                )
            )
        ));

        $this->add(array(
            'name' => 'pwd_ftp',
            'required' => true,
            'filters' => array(
                array('name' => 'StripTags'),
                array('name' => 'StringTrim')
            ),
            'validators' => array(
                array(
                    'name' => 'StringLength',
                    'options' => array(
                        'encoding' => 'UTF-8',
                        'min' => '1',
                        'max' => '255'
                    )
                )
            )
        ));

        $this->add(array(
            'name' => 'port_ftp',
            'required' => true,
            'filters' => array(
                array('name' => 'StripTags'),
                array('name' => 'StringTrim')
            ),
            'validators' => array(
                array(
                    'name' => 'StringLength',
                    'options' => array(
                        'encoding' => 'UTF-8',
                        'min' => '1',
                        'max' => '45'
                    )
                )
            )
        ));

        $this->add(array(
            'name' => 'id_server',
            'required' => false,
        ));

        //...
    }
}
