<?php
namespace Application\Model;

use Zend\Db\Adapter\Adapter;
use Zend\Db\Sql\Sql;

/**
 * Class AccountModel
 * @package Application\Model
 */
class AccountModel
{
    const TABLE = 'ws_account';

    /**
     * @var array
     */
    protected $_whitelist = array(
        'id',
        'id_domain',
        'id_type_account',
        'fullname',
        'usermail',
        'pwd',
        'info',
    );
    /**
     * @var \Zend\Db\Adapter\Adapter
     */
    public $adapter;

    /**
     * @var \Zend\Db\Sql\Sql
     */
    public $sql;

    /**
     * @param Adapter $adapter
     */
    public function __construct(Adapter $adapter)
    {
        $this->adapter = $adapter;
        $this->sql     = new Sql($adapter);
    }

    /**
     * @param $data
     * @return mixed|null
     */
    public function insert($data)
    {
        $values = array_intersect_key($data, array_flip($this->_whitelist));

        $insert = $this->sql->insert(self::TABLE);
        $insert->values($values);

        $statement = $this->sql->prepareStatementForSqlObject($insert);
        return $statement->execute()->getGeneratedValue();
    }

    /**
     * @param $id
     * @param array $data
     * @return mixed|null
     */
    public function update($id, array $data)
    {
        $values = array_intersect_key($data, array_flip($this->_whitelist));

        $where = new \Zend\Db\Sql\Where();
        $where->equalTo('id', (int)$id);

        $update = $this->sql->update(self::TABLE);
        $update->set($values)->where($where);

        $statement = $this->sql->prepareStatementForSqlObject($update);
        return $statement->execute()->getGeneratedValue();
    }

    /**
     * @param $id
     * @return \Zend\Db\Adapter\Driver\ResultInterface
     */
    public function delete($id)
    {
        $delete = $this->sql->delete(self::TABLE);
        $delete->where(array(
            'id' => $id
        ));

        $deleteStatement = $this->sql->prepareStatementForSqlObject($delete);
        return $deleteStatement->execute();
    }

    /**
     * @param array $filterBy
     * @return \Zend\Db\Adapter\Driver\ResultInterface
     */
    public function getList(array $filterBy = array())
    {
        $select = $this->sql->select();
        $select->from(array('a' => self::TABLE));
        $select->join(array('tp' => 'ws_type_account'), 'tp.id = a.id_type_account', array('name_type_account' => 'fullname'));

        $select->where($filterBy);
        $select->order('id ASC');

        $statement = $this->sql->prepareStatementForSqlObject($select);
        $dataset   = $statement->execute();
        return $dataset;
    }

    /**
     * @param array $filterBy
     * @return mixed
     */
    public function find(array $filterBy = array())
    {
        $select = $this->sql->select();
        $select->from(array('a' => self::TABLE));
        $select->join(array('tp' => 'ws_type_account'), 'tp.id = a.id_type_account', array('name_type_account' => 'fullname'));
        $select->where($filterBy);

        $statement = $this->sql->prepareStatementForSqlObject($select);
        return $statement->execute()->current();
    }

    /**
     * @param int $domain
     * @return \Zend\Db\Adapter\Driver\ResultInterface
     */
    public function deleteAllByDomain($domain = 0)
    {
        $delete = $this->sql->delete(self::TABLE);
        $delete->where(array(
            'id_domain' => $domain
        ));

        $deleteStatement = $this->sql->prepareStatementForSqlObject($delete);
        return $deleteStatement->execute();
    }

    /**
     * @return mixed
     */
    public function count()
    {
        $select = $this->sql->select();
        $select->from(self::TABLE);
        $select->columns(array('min' => new \Zend\Db\Sql\Expression('COUNT(*)')));
        $statement = $this->sql->prepareStatementForSqlObject($select);
        return $statement->execute()->current();
    }
}