<?php
namespace Application\Model;

use Zend\Db\Adapter\Adapter;
use Zend\Db\Sql\Sql;

/**
 * Class SettingModel
 * @package Application\Model
 */
class SettingModel
{
    const TABLE = 'ws_setting';

    /**
     * @var array
     */
    protected $_whitelist = array(
        'id',
        'name',
        'surname',
        'usermail',
        'email',
        'pwd',
        'language',
        'last_accessed',
        'company',
        'vat',
        'id_role',
    	'api_key',	
    	'send_email',
    	'from_mail',
    	'from_name',
    	'host',
    	'port',
    	'username',
    	'password',	
    	'question',
    	'answer',
    	'token',									
    );

    /**
     * @var \Zend\Db\Adapter\Adapter
     */
    public $adapter;

    /**
     * @var \Zend\Db\Sql\Sql
     */
    public $sql;

    /**
     * @param Adapter $adapter
     */
    public function __construct(Adapter $adapter)
    {
        $this->adapter = $adapter;
        $this->sql = new Sql($adapter);
    }

    /**
     * @param $data
     * @return mixed|null
     */
    public function insert($data)
    {
        $values = array_intersect_key($data, array_flip($this->_whitelist));

        $insert = $this->sql->insert(self::TABLE);
        $insert->values($values);

        $statement = $this->sql->prepareStatementForSqlObject($insert);
        return $statement->execute()->getGeneratedValue();
    }

    /**
     * @param $id
     * @param array $data
     * @return mixed|null
     */
    public function update($id, array $data)
    {
        $values = array_intersect_key($data, array_flip($this->_whitelist));

        $where = new \Zend\Db\Sql\Where();
        $where->equalTo('id', (int)$id);

        $update = $this->sql->update(self::TABLE);
        $update->set($values)->where($where);

        $statement = $this->sql->prepareStatementForSqlObject($update);
        return $statement->execute()->getGeneratedValue();
    }

    /**
     * @param $id
     * @return \Zend\Db\Adapter\Driver\ResultInterface
     */
    public function delete($id)
    {
        $delete = $this->sql->delete(self::TABLE);
        $delete->where(array(
            'id' => $id
        ));

        $deleteStatement = $this->sql->prepareStatementForSqlObject($delete);
        return $deleteStatement->execute();
    }

    /**
     * @param array $filterBy
     * @return \Zend\Db\Adapter\Driver\ResultInterface
     */
    public function getList(array $filterBy = array())
    {
        $select = $this->sql->select();
        $select->from(self::TABLE);
        $select->where($filterBy);
        $select->order('created DESC');

        $statement = $this->sql->prepareStatementForSqlObject($select);
        $dataset = $statement->execute();
        return $dataset;
    }

    /**
     * @param array $filterBy
     * @return mixed
     */
    public function find(array $filterBy = array())
    {
        $select = $this->sql->select();
        $select->from(self::TABLE);
        $select->where($filterBy);

        $statement = $this->sql->prepareStatementForSqlObject($select);
        return $statement->execute()->current();
    }

    /**
     * @param $id
     * @return mixed
     */
    public function getRole($id)
    {
        $select = $this->sql->select();
        $select->from(array('s' => self::TABLE))
            ->columns(array('id'))
            ->join(array('r' => 'ws_role'), 'r.id = s.id_role', 'role')
            ->where(array('s.id' => $id));
        $statement = $this->sql->prepareStatementForSqlObject($select);
        return $statement->execute()->current();
    }

    /**
     * @param $id
     */
    public function touch($id)
    {
        $this->update($id, array(
            'last_accessed' => date('Y-m-d H:i:s')
        ));
    }

    /**
     * @return \Zend\Db\Adapter\Driver\ResultInterface
     */
    public function getInstall()
    {
        $select = $this->sql->select();
        $select->from(self::TABLE);

        $statement = $this->sql->prepareStatementForSqlObject($select);
        $dataset = $statement->execute()->count();
        return $dataset;
    }
    
    /**
     * @return string
     */
    public function getApiKey($id)
    {
    	$select = $this->sql->select();
    	$select->from(self::TABLE);
    	$select->columns(array('api_key'));
    	$select->where(array(
    		'id' => $id
    	));
    	
    	$statement = $this->sql->prepareStatementForSqlObject($select);
    	return $statement->execute()->current();
    }
}