<?php
namespace Application\Service;

use Zend\ServiceManager\ServiceLocatorAwareInterface;
use Zend\ServiceManager\ServiceLocatorInterface;
use Zend\Crypt\BlockCipher;

/**
 * Class InstallService
 * @package Application\Service
 */
class InstallService implements ServiceLocatorAwareInterface
{
    /**
     *
     */
    const ROLE_ADMINISTRATOR = 1;

	/**
     * @var ServiceLocatorInterface
     */
    protected $_ServiceLocator;

    /**
     * @param \Zend\ServiceManager\ServiceLocatorInterface $ServiceLocator
     */
    public function setServiceLocator(ServiceLocatorInterface $ServiceLocator)
    {
        $this->_ServiceLocator = $ServiceLocator;
    }

    /**
     * @return \Zend\ServiceManager\ServiceLocatorInterface
     */
    public function getServiceLocator()
    {
        return $this->_ServiceLocator;
    }

    /**
     * @return array|object
     */
    protected function getModelSetting()
    {
    	return $this->getServiceLocator()->get('Application\Model\Setting');
    }

    /**
     * @param string $model
     * @return array
     */
    public function install(array $data = array())
    {    
    	$bcrypt = new \Zend\Crypt\Password\Bcrypt();
        $data['pwd'] = $bcrypt->create($data['pwd']);
        $data['id_role'] = self::ROLE_ADMINISTRATOR;
        $data['api_key'] = $bcrypt->create(\Zend\Math\Rand::getString(32));
        $data['token'] = sha1(\Zend\Math\Rand::getString(32));
		$id = $this->getModelSetting()->insert($data);

		if(!empty($id)) {
			
			$BC = $this->getServiceLocator()->get('block_cipher');
			$blockCipher = BlockCipher::factory('mcrypt', array('algo' => $BC['algo']));
			$apiKey = $this->getModelSetting()->find(array(
				'id' => $id,
			));
			
			$blockCipher->setKey($apiKey['api_key']);
			$this->getModelSetting()->update($id, array(
				'answer' => $blockCipher->encrypt($data['answer'])
			));
			
			return TRUE;
		}
		
    }

    /**
     * @return bool
     */
    public function getInstall()
    {
    	$row = $this->getModelSetting()->getInstall();
    	return $row == 0 OR $row != 1 ? TRUE : FALSE;
    }
}